﻿Imports GrapeCity.ActiveReports.Design
Imports GrapeCity.ActiveReports.Design.Resources
Imports GrapeCity.ActiveReports

Imports System.IO

Public Class UnifiedDesignerForm

    Public Sub New()

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        'Populating the ToolBox,reportExplorer and Propertygrid
        Me.reportdesigner.Toolbox = Me.reporttoolbox 'Attaches the toolbox to the report designer
        Me.reportExplorer.ReportDesigner = Me.reportdesigner 'Attaches the report explorer to the report designer
        Me.reportdesigner.PropertyGrid = Me.reportpropertyGrid 'Attaches the Property Grid to the report designer
        'Populating the Menu
        Dim toolstrip As ToolStrip = Me.reportdesigner.CreateToolStrips(New DesignerToolStrips() {DesignerToolStrips.Menu})(0)
        Dim filemenu As ToolStripDropDownItem = DirectCast(toolstrip.Items(0), ToolStripDropDownItem)
        Me.CreateFileMenu(filemenu)
        Me.AppendToolStrips(0, New ToolStrip() {toolstrip})
        Me.AppendToolStrips(1, Me.reportdesigner.CreateToolStrips(New DesignerToolStrips() {DesignerToolStrips.Edit, DesignerToolStrips.Undo, DesignerToolStrips.Zoom}))
        Dim item As ToolStrip = Me.CreateReportToolbar()
        Me.AppendToolStrips(2, Me.reportdesigner.CreateToolStrips(New DesignerToolStrips() {DesignerToolStrips.Format, DesignerToolStrips.Layout}))

    End Sub
    'Adding DropDownItems to the ToolStripDropDownItem
    Private Sub CreateFileMenu(ByVal fileMenu As ToolStripDropDownItem)
        fileMenu.DropDownItems.Clear()
        fileMenu.DropDownItems.Add(New ToolStripMenuItem("New", Images.CmdNewReport, New EventHandler(AddressOf OnNew), DirectCast(131150, Keys)))
        fileMenu.DropDownItems.Add(New ToolStripMenuItem("Open", Images.CmdOpen, New EventHandler(AddressOf OnOpen), DirectCast(131151, Keys)))
        fileMenu.DropDownItems.Add(New ToolStripMenuItem("Export", Nothing, New EventHandler(AddressOf OnExport), DirectCast(131152, Keys)))

        fileMenu.DropDownItems.Add(New ToolStripMenuItem("Save", Images.CmdSave, New EventHandler(AddressOf OnSave), DirectCast(131155, Keys)))
        fileMenu.DropDownItems.Add(New ToolStripMenuItem("Save As", Images.CmdSaveAs, New EventHandler(AddressOf OnSaveAs)))
        fileMenu.DropDownItems.Add(New ToolStripSeparator())
        fileMenu.DropDownItems.Add(New ToolStripButton("Exit", Nothing, New EventHandler(AddressOf OnExit)))

    End Sub
    'Getting the Designer to open a new Report on Menu Item "New" click
    Private Sub OnNew(sender As Object, e As EventArgs)
        If Me.ConfirmSaveChanges() Then
            Me.reportdesigner.ExecuteAction(DesignerAction.NewReport)
        End If
    End Sub
    'Getting the Designer to open a Report on Menu Item "Open" click
    Private Sub OnOpen(sender As Object, e As EventArgs)
        If Me.ConfirmSaveChanges() Then
            Me.reportdesigner.ExecuteAction(DesignerAction.FileOpen)
        End If
    End Sub
    'Getting the Designer to Save the Report on Menu Item "Save" click
    Private Sub OnSave(sender As Object, e As EventArgs)
        Me.reportdesigner.ExecuteAction(DesignerAction.FileSave)
    End Sub
    'Getting the Designer to Save the Report on Menu Item "Save As" click
    Private Sub OnSaveAs(sender As Object, e As EventArgs)
        Me.reportdesigner.ExecuteAction(DesignerAction.FileSaveAs)

    End Sub
    Private Sub OnExit(sender As Object, e As EventArgs)
        MyBase.Close()
    End Sub

    'Checking whether modifications have been made to the report loaded to the designer
    Private Function ConfirmSaveChanges() As Boolean
        If Me.reportdesigner.IsDirty Then
            Dim dialogresult__1 As DialogResult = MessageBox.Show("Report has been changed!!Do you wish to save it?", "", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question)
            If dialogresult__1 = DialogResult.Cancel Then
                Return False
            ElseIf dialogresult__1 = DialogResult.Yes Then
                Using _savedialog As New SaveFileDialog()
                    _savedialog.Filter = "rdlx files|*.rdlx"
                    _savedialog.DefaultExt = ".rdlx"


                    _savedialog.InitialDirectory = New DirectoryInfo(Application.ExecutablePath).Parent.Parent.Parent.FullName
                    If _savedialog.ShowDialog() = DialogResult.OK Then

                        Me.reportdesigner.SaveReport(New System.IO.FileInfo(_savedialog.FileName))
                        Me.reportdesigner.IsDirty = False
                    End If
                End Using

            End If
        End If

        Return True

    End Function
    Private Sub AppendToolStrips(row As Integer, toolStrips As IList(Of ToolStrip))
        Dim topToolStripPanel As ToolStripPanel = Me.ToolStripContainer1.TopToolStripPanel
        Dim num As Integer = toolStrips.Count
        While System.Threading.Interlocked.Decrement(num) >= 0
            topToolStripPanel.Join(toolStrips(num), row)
        End While
    End Sub
    Private Function CreateReportToolbar() As ToolStrip
        Return New ToolStrip(New ToolStripButton() {UnifiedDesignerForm.CreateToolStripButton("New", Images.CmdNewReport, New EventHandler(AddressOf OnNew), "New"), UnifiedDesignerForm.CreateToolStripButton("Open", Images.CmdOpen, New EventHandler(AddressOf OnOpen), "Open"), UnifiedDesignerForm.CreateToolStripButton("Save", Images.CmdSave, New EventHandler(AddressOf OnSave), "Save")})
    End Function
    Private Shared Function CreateToolStripButton(text As String, image As Image, handler As EventHandler, toolTip As String) As ToolStripButton
        Return New ToolStripButton(text, image, handler) With { _
         .DisplayStyle = ToolStripItemDisplayStyle.Image, _
            .ToolTipText = toolTip, _
         .DoubleClickEnabled = True _
        }
    End Function
    Private Sub OnExport(sender As Object, e As EventArgs)

           Try
                Dim _report As New GrapeCity.ActiveReports.SectionReport()
                _report = DirectCast(Me.reportdesigner.Report, GrapeCity.ActiveReports.SectionReport)
                _report.Run()
                Dim _export As New ExportProperties(_report.Document)
                _export.Show()
            Catch
                MessageBox.Show("There was an error in processing the report.Please redesign the same.")
            End Try
       

    End Sub

    Private Sub reportdesigner_DataSourceIconClick(sender As System.Object, e As GrapeCity.ActiveReports.Design.DataSourceIconClickEventArgs) Handles reportdesigner.DataSourceIconClick
        Dim dsForm As New DataSourceForm()
        If dsForm.ShowDialog() = DialogResult.OK Then
            DirectCast(reportdesigner.Report, SectionReport).DataSource = dsForm.DataSource
            e.Cancel = True
        Else
            e.Cancel = False
        End If
    End Sub
End Class

